macro_rules! define_text_enum {
($ty:ty) => { ... };
}Expand description
A helper macro to define a text-based enum that can be stored in a SQLite database.
The enum must implement Into<&'static str> and FromStr.
macro_rules! define_text_enum {
($ty:ty) => { ... };
}A helper macro to define a text-based enum that can be stored in a SQLite database.
The enum must implement Into<&'static str> and FromStr.