macro_rules! migrator {
($dir:literal) => { ... };
() => { ... };
}Expand description
A helper macro to define a migrate function that runs database migrations from a specified directory.
macro_rules! migrator {
($dir:literal) => { ... };
() => { ... };
}A helper macro to define a migrate function that runs database migrations from a specified directory.