pub struct TextWrapper<T>(pub T);Expand description
Wrapper type for implementing sqlx Encode and Decode for types by converting them to and from text.
Tuple Fields
0: TTrait Implementations
Sourceimpl<T: Debug> Debug for TextWrapper<T>
impl<T: Debug> Debug for TextWrapper<T>
Sourceimpl<'r> Decode<'r, Sqlite> for TextWrapper<Address>
impl<'r> Decode<'r, Sqlite> for TextWrapper<Address>
Sourcefn decode(value: SqliteValueRef<'r>) -> Result<Self, BoxDynError>
fn decode(value: SqliteValueRef<'r>) -> Result<Self, BoxDynError>
Decode a new value of this type using a raw value from the database.
Sourceimpl<'r, const N: usize> Decode<'r, Sqlite> for TextWrapper<FixedBytes<N>>
impl<'r, const N: usize> Decode<'r, Sqlite> for TextWrapper<FixedBytes<N>>
Sourcefn decode(value: SqliteValueRef<'r>) -> Result<Self, BoxDynError>
fn decode(value: SqliteValueRef<'r>) -> Result<Self, BoxDynError>
Decode a new value of this type using a raw value from the database.
Sourceimpl<'r, const BITS: usize, const LIMBS: usize> Decode<'r, Sqlite> for TextWrapper<Uint<BITS, LIMBS>>
impl<'r, const BITS: usize, const LIMBS: usize> Decode<'r, Sqlite> for TextWrapper<Uint<BITS, LIMBS>>
Sourcefn decode(value: SqliteValueRef<'r>) -> Result<Self, BoxDynError>
fn decode(value: SqliteValueRef<'r>) -> Result<Self, BoxDynError>
Decode a new value of this type using a raw value from the database.
Sourceimpl Encode<'_, Sqlite> for TextWrapper<Address>
impl Encode<'_, Sqlite> for TextWrapper<Address>
Sourcefn encode_by_ref(
&self,
args: &mut Vec<SqliteArgumentValue<'_>>,
) -> Result<IsNull, BoxDynError>
fn encode_by_ref( &self, args: &mut Vec<SqliteArgumentValue<'_>>, ) -> Result<IsNull, BoxDynError>
Sourcefn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
fn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
Writes the value of
self into buf in the expected format for the database.fn produces(&self) -> Option<<DB as Database>::TypeInfo>
fn size_hint(&self) -> usize
Sourceimpl<const N: usize> Encode<'_, Sqlite> for TextWrapper<FixedBytes<N>>
impl<const N: usize> Encode<'_, Sqlite> for TextWrapper<FixedBytes<N>>
Sourcefn encode_by_ref(
&self,
args: &mut Vec<SqliteArgumentValue<'_>>,
) -> Result<IsNull, BoxDynError>
fn encode_by_ref( &self, args: &mut Vec<SqliteArgumentValue<'_>>, ) -> Result<IsNull, BoxDynError>
Sourcefn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
fn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
Writes the value of
self into buf in the expected format for the database.fn produces(&self) -> Option<<DB as Database>::TypeInfo>
fn size_hint(&self) -> usize
Sourceimpl<const BITS: usize, const LIMBS: usize> Encode<'_, Sqlite> for TextWrapper<Uint<BITS, LIMBS>>
impl<const BITS: usize, const LIMBS: usize> Encode<'_, Sqlite> for TextWrapper<Uint<BITS, LIMBS>>
Sourcefn encode_by_ref(
&self,
args: &mut Vec<SqliteArgumentValue<'_>>,
) -> Result<IsNull, BoxDynError>
fn encode_by_ref( &self, args: &mut Vec<SqliteArgumentValue<'_>>, ) -> Result<IsNull, BoxDynError>
Sourcefn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
fn encode(
self,
buf: &mut <DB as Database>::ArgumentBuffer<'q>,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>where
Self: Sized,
Writes the value of
self into buf in the expected format for the database.fn produces(&self) -> Option<<DB as Database>::TypeInfo>
fn size_hint(&self) -> usize
Sourceimpl Type<Sqlite> for TextWrapper<Address>
impl Type<Sqlite> for TextWrapper<Address>
Sourcefn type_info() -> SqliteTypeInfo
fn type_info() -> SqliteTypeInfo
Returns the canonical SQL type for this Rust type. Read more
Sourcefn compatible(ty: &SqliteTypeInfo) -> bool
fn compatible(ty: &SqliteTypeInfo) -> bool
Determines if this Rust type is compatible with the given SQL type. Read more
Sourceimpl<const N: usize> Type<Sqlite> for TextWrapper<FixedBytes<N>>
impl<const N: usize> Type<Sqlite> for TextWrapper<FixedBytes<N>>
Sourcefn type_info() -> SqliteTypeInfo
fn type_info() -> SqliteTypeInfo
Returns the canonical SQL type for this Rust type. Read more
Sourcefn compatible(ty: &SqliteTypeInfo) -> bool
fn compatible(ty: &SqliteTypeInfo) -> bool
Determines if this Rust type is compatible with the given SQL type. Read more
Sourceimpl<const BITS: usize, const LIMBS: usize> Type<Sqlite> for TextWrapper<Uint<BITS, LIMBS>>
impl<const BITS: usize, const LIMBS: usize> Type<Sqlite> for TextWrapper<Uint<BITS, LIMBS>>
Sourcefn type_info() -> SqliteTypeInfo
fn type_info() -> SqliteTypeInfo
Returns the canonical SQL type for this Rust type. Read more
Sourcefn compatible(ty: &SqliteTypeInfo) -> bool
fn compatible(ty: &SqliteTypeInfo) -> bool
Determines if this Rust type is compatible with the given SQL type. Read more